@@ -48,7 +48,7 @@ class MachBunt;
 
 class MachBuntButton : public TQButton 
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 	public:
 	    	MachBuntButton(MachBunt *client, const char *name,
@@ -97,7 +97,7 @@ class MachBuntButton : public TQButton
 
 class MachBunt : public KDecoration
 {
-	Q_OBJECT
+	TQ_OBJECT
 
 	public:
 		MachBunt(KDecorationBridge* bridge, KDecorationFactory* factory);
@@ -156,7 +156,7 @@ class MachBunt : public KDecoration
 
 class BuntFactory : public TQObject, public KDecorationFactory
 {
-  Q_OBJECT
+  TQ_OBJECT
 
   public:
 
